# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nanit.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nanit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bnanit.proto\x12\x05nanit\"}\n\nSensorData\x12&\n\x0bsensor_type\x18\x01 \x02(\x0e\x32\x11.nanit.SensorType\x12\r\n\x05value\x18\x03 \x01(\x05\x12\x10\n\x08is_alert\x18\x04 \x01(\x08\x12\x11\n\ttimestamp\x18\x05 \x01(\x05\x12\x13\n\x0bvalue_milli\x18\x06 \x01(\x05\"a\n\rGetSensorData\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12\x13\n\x0btemperature\x18\x04 \x01(\x08\x12\x10\n\x08humidity\x18\x05 \x01(\x08\x12\r\n\x05light\x18\x06 \x01(\x08\x12\r\n\x05night\x18\x07 \x01(\x08\"l\n\nGetControl\x12\x0b\n\x03ptz\x18\x01 \x01(\x08\x12\x13\n\x0bnight_light\x18\x02 \x01(\x08\x12\x1b\n\x13night_light_timeout\x18\x03 \x01(\x08\x12\x1f\n\x17sensor_data_transfer_en\x18\x04 \x01(\x08\"\xdd\x02\n\x07\x43ontrol\x12.\n\x0bnight_light\x18\x03 \x01(\x0e\x32\x19.nanit.Control.NightLight\x12?\n\x14sensor_data_transfer\x18\x04 \x01(\x0b\x32!.nanit.Control.SensorDataTransfer\x12\x1f\n\x17\x66orce_connect_to_server\x18\x05 \x01(\x08\x12\x1b\n\x13night_light_timeout\x18\x06 \x01(\x05\x1ax\n\x12SensorDataTransfer\x12\r\n\x05sound\x18\x01 \x01(\x08\x12\x0e\n\x06motion\x18\x02 \x01(\x08\x12\x13\n\x0btemperature\x18\x03 \x01(\x08\x12\x10\n\x08humidity\x18\x04 \x01(\x08\x12\r\n\x05light\x18\x05 \x01(\x08\x12\r\n\x05night\x18\x06 \x01(\x08\")\n\nNightLight\x12\r\n\tLIGHT_OFF\x10\x00\x12\x0c\n\x08LIGHT_ON\x10\x01\"\xc0\x06\n\x08Settings\x12\x14\n\x0cnight_vision\x18\x02 \x01(\x08\x12/\n\x07sensors\x18\x07 \x03(\x0b\x32\x1e.nanit.Settings.SensorSettings\x12/\n\x07streams\x18\x08 \x03(\x0b\x32\x1e.nanit.Settings.StreamSettings\x12\x0e\n\x06volume\x18\t \x01(\x05\x12\x31\n\x0c\x61nti_flicker\x18\n \x01(\x0e\x32\x1b.nanit.Settings.AntiFlicker\x12\x12\n\nsleep_mode\x18\x0b \x01(\x08\x12\x17\n\x0fstatus_light_on\x18\x0c \x01(\x08\x12\x15\n\rmounting_mode\x18\x0f \x01(\x05\x12+\n\twifi_band\x18\x12 \x01(\x0e\x32\x18.nanit.Settings.WifiBand\x12\x13\n\x0bmic_mute_on\x18\x14 \x01(\x08\x1a\xfb\x01\n\x0eSensorSettings\x12&\n\x0bsensor_type\x18\x01 \x02(\x0e\x32\x11.nanit.SensorType\x12\x19\n\x11use_low_threshold\x18\x02 \x01(\x08\x12\x1a\n\x12use_high_threshold\x18\x03 \x01(\x08\x12\x15\n\rlow_threshold\x18\x04 \x01(\x05\x12\x16\n\x0ehigh_threshold\x18\x05 \x01(\x05\x12\x1b\n\x13sample_interval_sec\x18\x06 \x01(\x05\x12\x1c\n\x14trigger_interval_sec\x18\x07 \x01(\x05\x12 \n\x18use_milli_for_thresholds\x18\x08 \x01(\x08\x1a\x9c\x01\n\x0eStreamSettings\x12#\n\x02id\x18\x01 \x02(\x0e\x32\x17.nanit.StreamIdentifier\x12\x0f\n\x07\x62itrate\x18\x02 \x01(\x05\x12\x17\n\x0f\x65\x63onomy_bitrate\x18\x03 \x01(\x05\x12\x13\n\x0b\x65\x63onomy_fps\x18\x04 \x01(\x05\x12\x14\n\x0c\x62\x65st_bitrate\x18\x05 \x01(\x05\x12\x10\n\x08\x62\x65st_fps\x18\x06 \x01(\x05\"%\n\x0b\x41ntiFlicker\x12\n\n\x06\x46R50HZ\x10\x00\x12\n\n\x06\x46R60HZ\x10\x01\"/\n\x08WifiBand\x12\x07\n\x03\x41NY\x10\x00\x12\x0c\n\x08\x46R2_4GHZ\x10\x01\x12\x0c\n\x08\x46R5_0GHZ\x10\x02\"\xaa\x02\n\x06Status\x12\x1a\n\x12upgrade_downloaded\x18\x01 \x01(\x08\x12>\n\x14\x63onnection_to_server\x18\x02 \x01(\x0e\x32 .nanit.Status.ConnectionToServer\x12\x17\n\x0f\x63urrent_version\x18\x03 \x01(\t\x12!\n\x04mode\x18\x04 \x01(\x0e\x32\x13.nanit.MountingMode\x12\x1b\n\x13is_security_upgrade\x18\x05 \x01(\x08\x12\x1a\n\x12\x64ownloaded_version\x18\x06 \x01(\t\x12\x18\n\x10hardware_version\x18\x07 \x01(\t\"5\n\x12\x43onnectionToServer\x12\x10\n\x0c\x44ISCONNECTED\x10\x00\x12\r\n\tCONNECTED\x10\x01\"V\n\x08Playback\x12&\n\x06status\x18\x01 \x02(\x0e\x32\x16.nanit.Playback.Status\"\"\n\x06Status\x12\x0b\n\x07STARTED\x10\x00\x12\x0b\n\x07STOPPED\x10\x01\"v\n\x06Stream\x12 \n\x04type\x18\x01 \x02(\x0e\x32\x12.nanit.Stream.Type\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0b\n\x03\x62ps\x18\x03 \x01(\x05\"0\n\x04Type\x12\t\n\x05LOCAL\x10\x00\x12\n\n\x06REMOTE\x10\x01\x12\x08\n\x04RTSP\x10\x02\x12\x07\n\x03P2P\x10\x03\"\xad\x01\n\tStreaming\x12#\n\x02id\x18\x01 \x02(\x0e\x32\x17.nanit.StreamIdentifier\x12\'\n\x06status\x18\x02 \x02(\x0e\x32\x17.nanit.Streaming.Status\x12\x10\n\x08rtmp_url\x18\x03 \x02(\t\x12\x10\n\x08\x61ttempts\x18\x04 \x01(\x05\".\n\x06Status\x12\x0b\n\x07STARTED\x10\x00\x12\x0b\n\x07STOPPED\x10\x01\x12\n\n\x06PAUSED\x10\x02\"\x16\n\x07GetLogs\x12\x0b\n\x03url\x18\x01 \x02(\t\"\x18\n\tGetStatus\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\"\xa9\x03\n\x07Request\x12\n\n\x02id\x18\x01 \x02(\x05\x12 \n\x04type\x18\x02 \x02(\x0e\x32\x12.nanit.RequestType\x12#\n\tstreaming\x18\x04 \x01(\x0b\x32\x10.nanit.Streaming\x12!\n\x08settings\x18\x05 \x01(\x0b\x32\x0f.nanit.Settings\x12\x1d\n\x06status\x18\x07 \x01(\x0b\x32\r.nanit.Status\x12$\n\nget_status\x18\x08 \x01(\x0b\x32\x10.nanit.GetStatus\x12-\n\x0fget_sensor_data\x18\x0c \x01(\x0b\x32\x14.nanit.GetSensorData\x12&\n\x0bsensor_data\x18\r \x03(\x0b\x32\x11.nanit.SensorData\x12\x1f\n\x07\x63ontrol\x18\x0f \x01(\x0b\x32\x0e.nanit.Control\x12!\n\x08playback\x18\x10 \x01(\x0b\x32\x0f.nanit.Playback\x12&\n\x0bget_control\x18\x11 \x01(\x0b\x32\x11.nanit.GetControl\x12 \n\x08get_logs\x18\x12 \x01(\x0b\x32\x0e.nanit.GetLogs\"\x80\x02\n\x08Response\x12\x12\n\nrequest_id\x18\x01 \x02(\x05\x12(\n\x0crequest_type\x18\x02 \x02(\x0e\x32\x12.nanit.RequestType\x12\x13\n\x0bstatus_code\x18\x03 \x02(\x05\x12\x16\n\x0estatus_message\x18\x04 \x01(\t\x12\x1d\n\x06status\x18\x05 \x01(\x0b\x32\r.nanit.Status\x12!\n\x08settings\x18\x06 \x01(\x0b\x32\x0f.nanit.Settings\x12&\n\x0bsensor_data\x18\t \x03(\x0b\x32\x11.nanit.SensorData\x12\x1f\n\x07\x63ontrol\x18\r \x01(\x0b\x32\x0e.nanit.Control\"\xa2\x01\n\x07Message\x12!\n\x04type\x18\x01 \x02(\x0e\x32\x13.nanit.Message.Type\x12\x1f\n\x07request\x18\x02 \x01(\x0b\x32\x0e.nanit.Request\x12!\n\x08response\x18\x03 \x01(\x0b\x32\x0f.nanit.Response\"0\n\x04Type\x12\r\n\tKEEPALIVE\x10\x00\x12\x0b\n\x07REQUEST\x10\x01\x12\x0c\n\x08RESPONSE\x10\x02*\xe0\x06\n\x0bRequestType\x12\x11\n\rPUT_STREAMING\x10\x02\x12\x11\n\rGET_STREAMING\x10\x03\x12\x10\n\x0cGET_SETTINGS\x10\x04\x12\x10\n\x0cPUT_SETTINGS\x10\x05\x12\x0f\n\x0bGET_CONTROL\x10\x06\x12\x0f\n\x0bPUT_CONTROL\x10\x07\x12\x0e\n\nGET_STATUS\x10\x08\x12\x0e\n\nPUT_STATUS\x10\t\x12\x13\n\x0fPUT_SENSOR_DATA\x10\x0b\x12\x13\n\x0fGET_SENSOR_DATA\x10\x0c\x12\x10\n\x0cGET_UCTOKENS\x10\r\x12\x10\n\x0cPUT_UCTOKENS\x10\x0e\x12\x15\n\x11PUT_SETUP_NETWORK\x10\x0f\x12\x14\n\x10PUT_SETUP_SERVER\x10\x10\x12\x10\n\x0cGET_FIRMWARE\x10\x11\x12\x10\n\x0cPUT_FIRMWARE\x10\x12\x12\x10\n\x0cGET_PLAYBACK\x10\x13\x12\x10\n\x0cPUT_PLAYBACK\x10\x14\x12\x13\n\x0fGET_SOUNDTRACKS\x10\x15\x12\x16\n\x12GET_STATUS_NETWORK\x10\x16\x12\x15\n\x11GET_LIST_NETWORKS\x10\x17\x12\x0c\n\x08GET_LOGS\x10\x18\x12\x11\n\rGET_BANDWIDTH\x10\x19\x12\x17\n\x13GET_AUDIO_STREAMING\x10\x1a\x12\x17\n\x13PUT_AUDIO_STREAMING\x10\x1b\x12\x12\n\x0eGET_WIFI_SETUP\x10\x1c\x12\x12\n\x0ePUT_WIFI_SETUP\x10\x1d\x12\x13\n\x0fPUT_STING_START\x10\x1e\x12\x12\n\x0ePUT_STING_STOP\x10\x1f\x12\x14\n\x10PUT_STING_STATUS\x10 \x12\x13\n\x0fPUT_STING_ALERT\x10\"\x12\x12\n\x0ePUT_KEEP_ALIVE\x10#\x12\x14\n\x10GET_STING_STATUS\x10$\x12\x12\n\x0ePUT_STING_TEST\x10%\x12\x16\n\x12PUT_RTSP_STREAMING\x10&\x12\x0f\n\x0bGET_UOM_URI\x10\'\x12\x0b\n\x07GET_UOM\x10(\x12\x0b\n\x07PUT_UOM\x10)\x12\x10\n\x0cGET_AUTH_KEY\x10*\x12\x10\n\x0cPUT_AUTH_KEY\x10+\x12\x0e\n\nPUT_HEALTH\x10,\x12\x13\n\x0fPUT_TCP_REQUEST\x10-\x12\x13\n\x0fGET_STING_START\x10.\x12\x10\n\x0cGET_LOGS_URI\x10/*X\n\nSensorType\x12\t\n\x05SOUND\x10\x00\x12\n\n\x06MOTION\x10\x01\x12\x0f\n\x0bTEMPERATURE\x10\x02\x12\x0c\n\x08HUMIDITY\x10\x03\x12\t\n\x05LIGHT\x10\x04\x12\t\n\x05NIGHT\x10\x05*6\n\x10StreamIdentifier\x12\x07\n\x03\x44VR\x10\x00\x12\r\n\tANALYTICS\x10\x01\x12\n\n\x06MOBILE\x10\x02*1\n\x0cMountingMode\x12\t\n\x05STAND\x10\x00\x12\n\n\x06TRAVEL\x10\x01\x12\n\n\x06SWITCH\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nanit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REQUESTTYPE']._serialized_start=3133
  _globals['_REQUESTTYPE']._serialized_end=3997
  _globals['_SENSORTYPE']._serialized_start=3999
  _globals['_SENSORTYPE']._serialized_end=4087
  _globals['_STREAMIDENTIFIER']._serialized_start=4089
  _globals['_STREAMIDENTIFIER']._serialized_end=4143
  _globals['_MOUNTINGMODE']._serialized_start=4145
  _globals['_MOUNTINGMODE']._serialized_end=4194
  _globals['_SENSORDATA']._serialized_start=22
  _globals['_SENSORDATA']._serialized_end=147
  _globals['_GETSENSORDATA']._serialized_start=149
  _globals['_GETSENSORDATA']._serialized_end=246
  _globals['_GETCONTROL']._serialized_start=248
  _globals['_GETCONTROL']._serialized_end=356
  _globals['_CONTROL']._serialized_start=359
  _globals['_CONTROL']._serialized_end=708
  _globals['_CONTROL_SENSORDATATRANSFER']._serialized_start=545
  _globals['_CONTROL_SENSORDATATRANSFER']._serialized_end=665
  _globals['_CONTROL_NIGHTLIGHT']._serialized_start=667
  _globals['_CONTROL_NIGHTLIGHT']._serialized_end=708
  _globals['_SETTINGS']._serialized_start=711
  _globals['_SETTINGS']._serialized_end=1543
  _globals['_SETTINGS_SENSORSETTINGS']._serialized_start=1045
  _globals['_SETTINGS_SENSORSETTINGS']._serialized_end=1296
  _globals['_SETTINGS_STREAMSETTINGS']._serialized_start=1299
  _globals['_SETTINGS_STREAMSETTINGS']._serialized_end=1455
  _globals['_SETTINGS_ANTIFLICKER']._serialized_start=1457
  _globals['_SETTINGS_ANTIFLICKER']._serialized_end=1494
  _globals['_SETTINGS_WIFIBAND']._serialized_start=1496
  _globals['_SETTINGS_WIFIBAND']._serialized_end=1543
  _globals['_STATUS']._serialized_start=1546
  _globals['_STATUS']._serialized_end=1844
  _globals['_STATUS_CONNECTIONTOSERVER']._serialized_start=1791
  _globals['_STATUS_CONNECTIONTOSERVER']._serialized_end=1844
  _globals['_PLAYBACK']._serialized_start=1846
  _globals['_PLAYBACK']._serialized_end=1932
  _globals['_PLAYBACK_STATUS']._serialized_start=1898
  _globals['_PLAYBACK_STATUS']._serialized_end=1932
  _globals['_STREAM']._serialized_start=1934
  _globals['_STREAM']._serialized_end=2052
  _globals['_STREAM_TYPE']._serialized_start=2004
  _globals['_STREAM_TYPE']._serialized_end=2052
  _globals['_STREAMING']._serialized_start=2055
  _globals['_STREAMING']._serialized_end=2228
  _globals['_STREAMING_STATUS']._serialized_start=2182
  _globals['_STREAMING_STATUS']._serialized_end=2228
  _globals['_GETLOGS']._serialized_start=2230
  _globals['_GETLOGS']._serialized_end=2252
  _globals['_GETSTATUS']._serialized_start=2254
  _globals['_GETSTATUS']._serialized_end=2278
  _globals['_REQUEST']._serialized_start=2281
  _globals['_REQUEST']._serialized_end=2706
  _globals['_RESPONSE']._serialized_start=2709
  _globals['_RESPONSE']._serialized_end=2965
  _globals['_MESSAGE']._serialized_start=2968
  _globals['_MESSAGE']._serialized_end=3130
  _globals['_MESSAGE_TYPE']._serialized_start=3082
  _globals['_MESSAGE_TYPE']._serialized_end=3130
# @@protoc_insertion_point(module_scope)
